@@ -135,7 +135,7 @@ QT_BEGIN_NAMESPACE
         \l{https://msdn.microsoft.com/en-us/library/windows/desktop/ms740522(v=vs.85).aspx}
         {Winsock 2 Socket Handle}.
 
-        \li With WinRT and on INTEGRITY, the returned value is the
+        \li On INTEGRITY, the returned value is the
         QTcpSocket socket descriptor and the type is defined by
         \l{QTcpSocket::socketDescriptor}{socketDescriptor}.
 
@@ -151,6 +151,11 @@ QT_BEGIN_NAMESPACE
     \reimp
 */
 
+/*!
+    \fn qint64 QLocalSocket::skipData(qint64 maxSize)
+    \reimp
+*/
+
 /*!
     \fn qint64 QLocalSocket::writeData(const char *data, qint64 c)
     \reimp
@@ -214,7 +219,7 @@ QT_BEGIN_NAMESPACE
     Attempts to close the socket. If there is pending data waiting to be
     written, QLocalSocket will enter ClosingState and wait until all data
     has been written. Eventually, it will enter UnconnectedState and emit
-    the disconnectedFromServer() signal.
+    the disconnected() signal.
 
     \sa connectToServer()
 */
@@ -329,13 +334,6 @@ QT_BEGIN_NAMESPACE
     \sa connectToServer(), disconnectFromServer(), abort(), connected()
 */
 
-/*!
-    \fn void QLocalSocket::error(QLocalSocket::LocalSocketError socketError)
-    \obsolete
-
-    Use errorOccurred() instead.
-*/
-
 /*!
     \fn void QLocalSocket::errorOccurred(QLocalSocket::LocalSocketError socketError)
     \since 5.15
@@ -372,9 +370,6 @@ QLocalSocket::QLocalSocket(QObject * parent)
 {
     Q_D(QLocalSocket);
     d->init();
-
-    // Support the deprecated error() signal:
-    connect(this, &QLocalSocket::errorOccurred, this, QOverload<QLocalSocket::LocalSocketError>::of(&QLocalSocket::error));
 }
 
 /*!
@@ -552,6 +547,9 @@ QDebug operator<<(QDebug debug, QLocalSocket::LocalSocketError error)
     case QLocalSocket::UnknownSocketError:
         debug << "QLocalSocket::UnknownSocketError";
         break;
+    case QLocalSocket::OperationError:
+        debug << "QLocalSocket::OperationError";
+        break;
     default:
         debug << "QLocalSocket::SocketError(" << int(error) << ')';
         break;
